@@ -1,5 +1,4 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
- *
+/*
  * Copyright (C) 2008-2013 Red Hat, Inc.
  *
  * Licensed under GPL version 2 or later.
@@ -7,17 +6,17 @@
  * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
-#ifndef __GDU_FORMAT_DISK_DIALOG_H__
-#define __GDU_FORMAT_DISK_DIALOG_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include "gdutypes.h"
 
 G_BEGIN_DECLS
 
+#define GDU_TYPE_FORMAT_DISK_DIALOG (gdu_format_disk_dialog_get_type ())
+G_DECLARE_FINAL_TYPE (GduFormatDiskDialog, gdu_format_disk_dialog, GDU, FORMAT_DISK_DIALOG, GtkDialog)
+
 void     gdu_format_disk_dialog_show (GduWindow    *window,
                                       UDisksObject *object);
 
 G_END_DECLS
-
-#endif /* __GDU_FORMAT_DISK_DIALOG_H__ */
